
import { createWebHistory, createRouter } from 'vue-router'
/* Layout */
import Layout from '@/layout'

/**
 * Note: 路由配置项
 *
 * hidden: true                     // 当设置 true 的时候该路由不会再侧边栏出现 如401，login等页面，或者如一些编辑页面/edit/1
 * alwaysShow: true                 // 当你一个路由下面的 children 声明的路由大于1个时，自动会变成嵌套的模式--如组件页面
 *                                  // 只有一个时，会将那个子路由当做根路由显示在侧边栏--如引导页面
 *                                  // 若你想不管路由下面的 children 声明的个数都显示你的根路由
 *                                  // 你可以设置 alwaysShow: true，这样它就会忽略之前定义的规则，一直显示根路由
 * redirect: noRedirect             // 当设置 noRedirect 的时候该路由在面包屑导航中不可被点击
 * name:'router-name'               // 设定路由的名字，一定要填写不然使用<keep-alive>时会出现各种问题
 * query: '{"id": 1, "name": "ry"}' // 访问路由的默认传递参数
 * roles: ['admin', 'common']       // 访问路由的角色权限
 * permissions: ['a:a:a', 'b:b:b']  // 访问路由的菜单权限
 * meta : {
    noCache: true                   // 如果设置为true，则不会被 <keep-alive> 缓存(默认 false)
    title: 'title'                  // 设置该路由在侧边栏和面包屑中展示的名字
    icon: 'svg-name'                // 设置该路由的图标，对应路径src/assets/icons/svg
    breadcrumb: false               // 如果设置为false，则不会在breadcrumb面包屑中显示
    activeMenu: '/system/user'      // 当路由设置了该属性，则会高亮相对应的侧边栏。
  }
 */

// 公共路由
export const constantRoutes = [
  {
    path: '/redirect',
    component: Layout,
    hidden: true,
    children: [
      {
        path: '/redirect/:path(.*)',
        component: () => import('@/views/redirect/index.vue')
      }
    ]
  },
  {
    path: '/login',
    component: () => import('@/views/login'),
    hidden: true
  },
  {
    path: '/register',
    component: () => import('@/views/register'),
    hidden: true
  },
  {
    path: "/:pathMatch(.*)*",
    component: () => import('@/views/error/404'),
    hidden: true
  },
  {
    path: '/401',
    component: () => import('@/views/error/401'),
    hidden: true
  },
  {
    path: "/icons",
    component: () => import("@/components/icons"),
    hidden: true,
  },
  {
    path: '',
    component: Layout,
    redirect: '/index',
    children: [
      {
        path: '/index',
        component: () => import('@/views/index'),
        name: 'Index',
        meta: { title: '首页', icon: 'chart', affix: true }
      }
    ]
  },
  {
    path: '/goods',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [
      {
        path: 'goodsManage/addGoods/:activeTab?',
        component: () => import('@/views/goods/goodsManage/addGoods'),
        name: 'addGoods',
        meta: { title: '新增商品', icon: '' }
      },
      {
        path: 'goodsManage/editGoods/:activeTab?',
        component: () => import('@/views/goods/goodsManage/editGoods'),
        name: 'editGoods',
        meta: { title: '编辑商品', icon: '' }
      },
      {
        path: 'goodsReview/auditGoods/:activeTab?',
        component: () => import('@/views/goods/goodsReview/auditGoods'),
        name: 'auditGoods',
        meta: {
          title: "商品审核",
          icon: "",
        },
      },
    ]
  },
  {
    path: '/order',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [
      {
        path: 'order/sendGoodsInfo/:activeTab?',
        component: () => import('@/views/order/sendGoodsInfo'),
        hidden: false,
        meta: {
          title: "去发货",
          icon: "star",
        },
        name: "sendGoodsInfo",
      },
      {
        path: 'order/orderDetails/:activeTab?',
        component: () => import('@/views/order/orderDetails'),
        hidden: false,
        meta: {
          title: "订单详情",
          icon: "star",
        },
        name: "orderDetails",
      },
    ]
  },
  {
    path: '/user',
    component: Layout,
    hidden: true,
    redirect: 'noredirect',
    children: [
      {
        path: 'profile/:activeTab?',
        component: () => import('@/views/system/user/profile/index'),
        name: 'Profile',
        meta: { title: '个人中心', icon: 'user' }
      }
    ]
  },
  {
    path: '/customer',
    name: "customer",
    component: Layout,
    hidden: false,
    alwaysShow: true,
    redirect: 'noredirect',
    meta: {
      icon: "peoples",
      link: null,
      noCache: false,
      title: "客户管理",
    },
    children: [
      {
        path: 'customer/customerManage',
        component: () => import('@/views/customer/customerManage'),
        name: 'customerManage',
        hidden: false,
        meta: {
          title: "客户信息管理",
          icon: "",
          noCache: false,
          link: null,
        },
      },
      {
        path: 'customer/customerCategory',
        component: () => import('@/views/customer/customerCategory'),
        name: 'customerCategory',
        hidden: false,
        meta: {
          title: "客户分类设置",
          icon: "",
          noCache: false,
          link: null,
        },
      }
    ],
  },
  {
    path: '/goods',
    name: "goods",
    component: Layout,
    hidden: false,
    alwaysShow: true,
    redirect: 'noredirect',
    meta: {
      icon: "example",
      link: null,
      noCache: false,
      title: "商品中心",
    },
    children: [
      {
        path: 'goods/goodsManage',
        component: () => import('@/views/goods/goodsManage/index'),
        name: 'goodsManage',
        hidden: false,
        meta: {
          title: "商品信息管理",
          icon: "",
          noCache: false,
          link: null,
        },
      },
      {
        path: 'goods/goodsCategory',
        component: () => import('@/views/goods/goodsCategory/index'),
        name: 'goodsCategory',
        hidden: false,
        meta: {
          title: "商品分类设置",
          icon: "",
          noCache: false,
          link: null,
        },
      },
      {
        path: 'goods/contrabandManage',
        component: () => import('@/views/goods/contrabandManage/index'),
        name: 'contrabandManage',
        hidden: false,
        meta: {
          title: "违禁物品管理",
          icon: "",
          noCache: false,
          link: null,
        },
      },
      {
        path: 'goods/goodsReview',
        component: () => import('@/views/goods/goodsReview/index'),
        name: 'goodsReview',
        hidden: false,
        meta: {
          title: "上架审核设置",
          icon: "",
          noCache: false,
          link: null,
        },
      },
    ],
  },
  {
    path: '/plant',
    name: "plant",
    component: Layout,
    hidden: false,
    alwaysShow: true,
    redirect: 'noredirect',
    meta: {
      icon: "sunny",
      link: null,
      noCache: false,
      title: "智慧种植",
    },
    children: [
      {
        path: 'plant/ambient',
        component: () => import('@/views/plant/ambient'),
        name: 'ambient',
        hidden: false,
        meta: {
          title: "农业环境监测",
          icon: "",
          noCache: false,
          link: null,
        },
      },
      {
        path: 'plant/control',
        component: () => import('@/views/plant/control'),
        name: 'control',
        hidden: false,
        meta: {
          title: "生产管理控制",
          icon: "",
          noCache: false,
          link: null,
        },
      }
    ],
  },
  {
    path: '/trade',
    name: "trade",
    component: Layout,
    hidden: false,
    alwaysShow: true,
    redirect: 'noredirect',
    meta: {
      icon: "money",
      link: null,
      noCache: false,
      title: "电商交易",
    },
    children: [
      {
        path: 'trade/agriculturalinputstrading',
        component: () => import('@/views/trade/agriculturalinputstrading'),
        name: 'agriculturalinputstrading',
        hidden: false,
        meta: {
          title: "农资交易",
          icon: "",
          noCache: false,
          link: null,
        },
      },
      {
        path: 'trade/supplierServices',
        component: () => import('@/views/trade/supplierServices'),
        name: 'supplierServices',
        hidden: false,
        meta: {
          title: "供应商服务",
          icon: "",
          noCache: false,
          link: null,
        },
      },
      {
        path: 'trade/procurementServices',
        component: () => import('@/views/trade/procurementServices'),
        name: 'procurementServices',
        hidden: false,
        meta: {
          title: "采购商服务",
          icon: "",
          noCache: false,
          link: null,
        },
      },
      {
        path: 'trade/landTransaction',
        component: () => import('@/views/trade/landTransaction'),
        name: 'landTransaction',
        hidden: false,
        meta: {
          title: "土地交易",
          icon: "",
          noCache: false,
          link: null,
        },
      },
    ],
  },
{
    path: '/brand',
    name: "brand",
    component: Layout,
    hidden: false,
    alwaysShow: true,
    redirect: 'noredirect',
    meta: {
      icon: "example",
      link: null,
      noCache: false,
      title: "公共品牌",
    },
    children: [
      {
        path: 'brand/informationManagement',
        component: () => import('@/views/brand/informationManagement/index'),
        hidden: false,
        meta: {
          title: "信息管理",
          icon: "",
          noCache: false,
          link: null,
        },
        name: "informationManagement",
      },
      {
        path: 'brand/applicationReview',
        component: () => import('@/views/brand/applicationReview/index'),
        hidden: false,
        meta: {
          title: "申请审核",
          icon: "",
          noCache: false,
          link: null,
        },
        name: "applicationReview",
      },
      {
        path: 'brand/renewal',
        component: () => import('@/views/brand/renewal/index'),
        hidden: false,
        meta: {
          title: "申请续期",
          icon: "",
          noCache: false,
          link: null,
        },
        name: "renewal",
      },
      // {
      //   path: 'brand/management',
      //   component: () => import('@/views/brand/management/index'),
      //   hidden: false,
      //   meta: {
      //     title: "品牌使用管理",
      //     icon: "",
      //     noCache: false,
      //     link: null,
      //   },
      //   name: "management",
      // },
    ],
  },
  {
    path: '/order',
    name: "order",
    component: Layout,
    hidden: false,
    meta: {
      title: "订单列表",
      icon: "documentation",
      noCache: false,
      link: null,
    },
    children: [
      {
        path: 'order/obligation',
        component: () => import('@/views/order/obligation'),
        hidden: false,
        meta: {
          title: "待付款",
          noCache: false,
          link: null,
        },
        name: "obligation",
      },
      {
        path: 'order/sendGoods',
        component: () => import('@/views/order/sendGoods'),
        hidden: false,
        meta: {
          title: "待发货",
          noCache: false,
          link: null,
        },
        name: "sendGoods",
      },
      {
        path: 'order/shipped',
        component: () => import('@/views/order/shipped'),
        hidden: false,
        meta: {
          title: "已发货",
          noCache: false,
          link: null,
        },
        name: "shipped",
      },
      {
        path: 'order/receivedGoods',
        component: () => import('@/views/order/receivedGoods'),
        hidden: false,
        meta: {
          title: "已收货",
          noCache: false,
          link: null,
        },
        name: "receivedGoods",
      },
      {
        path: 'order/completed',
        component: () => import('@/views/order/completed'),
        hidden: false,
        meta: {
          title: "已完成",
          noCache: false,
          link: null,
        },
        name: "completed",
      },
      {
        path: 'order/cancelled',
        component: () => import('@/views/order/cancelled'),
        hidden: false,
        meta: {
          title: "已取消",
          noCache: false,
          link: null,
        },
        name: "cancelled",
      },
      {
        path: 'order/salesService',
        component: () => import('@/views/order/salesService'),
        hidden: false,
        meta: {
          title: "退货/退款",
          noCache: false,
          link: null,
        },
        name: "salesService",
      },
      {
        path: 'order/refunded',
        component: () => import('@/views/order/refunded'),
        hidden: false,
        meta: {
          title: "已退货/退款",
          noCache: false,
          link: null,
        },
        name: "refunded",
      },

    ],
  },
]

// 动态路由，基于用户权限动态去加载
export const dynamicRoutes = [
  {
    path: '/system/user-auth',
    component: Layout,
    hidden: true,
    permissions: ['system:user:edit'],
    children: [
      {
        path: 'role/:userId(\\d+)',
        component: () => import('@/views/system/user/authRole'),
        name: 'AuthRole',
        meta: { title: '分配角色', activeMenu: '/system/user' }
      }
    ]
  },
  {
    path: '/system/role-auth',
    component: Layout,
    hidden: true,
    permissions: ['system:role:edit'],
    children: [
      {
        path: 'user/:roleId(\\d+)',
        component: () => import('@/views/system/role/authUser'),
        name: 'AuthUser',
        meta: { title: '分配用户', activeMenu: '/system/role' }
      }
    ]
  },
  {
    path: '/system/dict-data',
    component: Layout,
    hidden: true,
    permissions: ['system:dict:list'],
    children: [
      {
        path: 'index/:dictId(\\d+)',
        component: () => import('@/views/system/dict/data'),
        name: 'Data',
        meta: { title: '字典数据', activeMenu: '/system/dict' }
      }
    ]
  },
  {
    path: '/monitor/job-log',
    component: Layout,
    hidden: true,
    permissions: ['monitor:job:list'],
    children: [
      {
        path: 'index/:jobId(\\d+)',
        component: () => import('@/views/monitor/job/log'),
        name: 'JobLog',
        meta: { title: '调度日志', activeMenu: '/monitor/job' }
      }
    ]
  },
  {
    path: '/tool/gen-edit',
    component: Layout,
    hidden: true,
    permissions: ['tool:gen:edit'],
    children: [
      {
        path: 'index/:tableId(\\d+)',
        component: () => import('@/views/tool/gen/editTable'),
        name: 'GenEdit',
        meta: { title: '修改生成配置', activeMenu: '/tool/gen' }
      }
    ]
  }
]

const router = createRouter({
  history: createWebHistory(),
  routes: constantRoutes,
  scrollBehavior(to, from, savedPosition) {
    if (savedPosition) {
      return savedPosition
    }
    return { top: 0 }
  },
})

export default router